# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from slack_beta_ti.models.admin_conversations_archive_schema import AdminConversationsArchiveSchema
from slack_beta_ti.models.admin_conversations_convert_to_private_schema import AdminConversationsConvertToPrivateSchema
from slack_beta_ti.models.admin_conversations_create_schema import AdminConversationsCreateSchema
from slack_beta_ti.models.admin_conversations_delete_schema import AdminConversationsDeleteSchema
from slack_beta_ti.models.admin_conversations_get_conversation_prefs_schema import AdminConversationsGetConversationPrefsSchema
from slack_beta_ti.models.admin_conversations_get_teams_schema import AdminConversationsGetTeamsSchema
from slack_beta_ti.models.admin_conversations_invite_schema import AdminConversationsInviteSchema
from slack_beta_ti.models.admin_conversations_rename_schema import AdminConversationsRenameSchema
from slack_beta_ti.models.admin_conversations_rename_schema1 import AdminConversationsRenameSchema1
from slack_beta_ti.models.admin_conversations_search_schema import AdminConversationsSearchSchema
from slack_beta_ti.models.admin_conversations_set_conversation_prefs_schema import AdminConversationsSetConversationPrefsSchema
from slack_beta_ti.models.admin_conversations_unarchive_schema import AdminConversationsUnarchiveSchema
from slack_beta_ti.models.default_success_template import DefaultSuccessTemplate

from slack_beta_ti.api_client import ApiClient, RequestSerialized
from slack_beta_ti.api_response import ApiResponse
from slack_beta_ti.rest import RESTResponseType


class AdminConversationsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def admin_conversations_archive(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to archive.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> AdminConversationsArchiveSchema:
        """admin_conversations_archive

        Archive a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to archive. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_archive_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsArchiveSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_conversations_archive_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to archive.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[AdminConversationsArchiveSchema]:
        """admin_conversations_archive

        Archive a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to archive. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_archive_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsArchiveSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_conversations_archive_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to archive.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_conversations_archive

        Archive a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to archive. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_archive_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsArchiveSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_conversations_archive_serialize(
        self,
        token,
        channel_id,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if channel_id is not None:
            _form_params.append(('channel_id', channel_id))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.conversations.archive',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_conversations_convert_to_private(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to convert to private.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> AdminConversationsConvertToPrivateSchema:
        """admin_conversations_convert_to_private

        Convert a public channel to a private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to convert to private. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_convert_to_private_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsConvertToPrivateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_conversations_convert_to_private_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to convert to private.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[AdminConversationsConvertToPrivateSchema]:
        """admin_conversations_convert_to_private

        Convert a public channel to a private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to convert to private. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_convert_to_private_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsConvertToPrivateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_conversations_convert_to_private_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to convert to private.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_conversations_convert_to_private

        Convert a public channel to a private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to convert to private. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_convert_to_private_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsConvertToPrivateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_conversations_convert_to_private_serialize(
        self,
        token,
        channel_id,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if channel_id is not None:
            _form_params.append(('channel_id', channel_id))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.conversations.convertToPrivate',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_conversations_create(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        name: Annotated[StrictStr, Field(description="Name of the public or private channel to create.")],
        is_private: Annotated[StrictBool, Field(description="When `true`, creates a private channel instead of a public channel")],
        description: Annotated[Optional[StrictStr], Field(description="Description of the public or private channel to create.")] = None,
        org_wide: Annotated[Optional[StrictBool], Field(description="When `true`, the channel will be available org-wide. Note: if the channel is not `org_wide=true`, you must specify a `team_id` for this channel")] = None,
        team_id: Annotated[Optional[StrictStr], Field(description="The workspace to create the channel in. Note: this argument is required unless you set `org_wide=true`.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> AdminConversationsCreateSchema:
        """admin_conversations_create

        Create a public or private channel-based conversation.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param name: Name of the public or private channel to create. (required)
        :type name: str
        :param is_private: When `true`, creates a private channel instead of a public channel (required)
        :type is_private: bool
        :param description: Description of the public or private channel to create.
        :type description: str
        :param org_wide: When `true`, the channel will be available org-wide. Note: if the channel is not `org_wide=true`, you must specify a `team_id` for this channel
        :type org_wide: bool
        :param team_id: The workspace to create the channel in. Note: this argument is required unless you set `org_wide=true`.
        :type team_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_create_serialize(
            token=token,
            name=name,
            is_private=is_private,
            description=description,
            org_wide=org_wide,
            team_id=team_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsCreateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_conversations_create_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        name: Annotated[StrictStr, Field(description="Name of the public or private channel to create.")],
        is_private: Annotated[StrictBool, Field(description="When `true`, creates a private channel instead of a public channel")],
        description: Annotated[Optional[StrictStr], Field(description="Description of the public or private channel to create.")] = None,
        org_wide: Annotated[Optional[StrictBool], Field(description="When `true`, the channel will be available org-wide. Note: if the channel is not `org_wide=true`, you must specify a `team_id` for this channel")] = None,
        team_id: Annotated[Optional[StrictStr], Field(description="The workspace to create the channel in. Note: this argument is required unless you set `org_wide=true`.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[AdminConversationsCreateSchema]:
        """admin_conversations_create

        Create a public or private channel-based conversation.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param name: Name of the public or private channel to create. (required)
        :type name: str
        :param is_private: When `true`, creates a private channel instead of a public channel (required)
        :type is_private: bool
        :param description: Description of the public or private channel to create.
        :type description: str
        :param org_wide: When `true`, the channel will be available org-wide. Note: if the channel is not `org_wide=true`, you must specify a `team_id` for this channel
        :type org_wide: bool
        :param team_id: The workspace to create the channel in. Note: this argument is required unless you set `org_wide=true`.
        :type team_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_create_serialize(
            token=token,
            name=name,
            is_private=is_private,
            description=description,
            org_wide=org_wide,
            team_id=team_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsCreateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_conversations_create_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        name: Annotated[StrictStr, Field(description="Name of the public or private channel to create.")],
        is_private: Annotated[StrictBool, Field(description="When `true`, creates a private channel instead of a public channel")],
        description: Annotated[Optional[StrictStr], Field(description="Description of the public or private channel to create.")] = None,
        org_wide: Annotated[Optional[StrictBool], Field(description="When `true`, the channel will be available org-wide. Note: if the channel is not `org_wide=true`, you must specify a `team_id` for this channel")] = None,
        team_id: Annotated[Optional[StrictStr], Field(description="The workspace to create the channel in. Note: this argument is required unless you set `org_wide=true`.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_conversations_create

        Create a public or private channel-based conversation.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param name: Name of the public or private channel to create. (required)
        :type name: str
        :param is_private: When `true`, creates a private channel instead of a public channel (required)
        :type is_private: bool
        :param description: Description of the public or private channel to create.
        :type description: str
        :param org_wide: When `true`, the channel will be available org-wide. Note: if the channel is not `org_wide=true`, you must specify a `team_id` for this channel
        :type org_wide: bool
        :param team_id: The workspace to create the channel in. Note: this argument is required unless you set `org_wide=true`.
        :type team_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_create_serialize(
            token=token,
            name=name,
            is_private=is_private,
            description=description,
            org_wide=org_wide,
            team_id=team_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsCreateSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_conversations_create_serialize(
        self,
        token,
        name,
        is_private,
        description,
        org_wide,
        team_id,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if name is not None:
            _form_params.append(('name', name))
        if description is not None:
            _form_params.append(('description', description))
        if is_private is not None:
            _form_params.append(('is_private', is_private))
        if org_wide is not None:
            _form_params.append(('org_wide', org_wide))
        if team_id is not None:
            _form_params.append(('team_id', team_id))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.conversations.create',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_conversations_delete(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to delete.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> AdminConversationsDeleteSchema:
        """admin_conversations_delete

        Delete a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to delete. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_delete_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsDeleteSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_conversations_delete_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to delete.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[AdminConversationsDeleteSchema]:
        """admin_conversations_delete

        Delete a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to delete. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_delete_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsDeleteSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_conversations_delete_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to delete.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_conversations_delete

        Delete a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to delete. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_delete_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsDeleteSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_conversations_delete_serialize(
        self,
        token,
        channel_id,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if channel_id is not None:
            _form_params.append(('channel_id', channel_id))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.conversations.delete',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_conversations_disconnect_shared(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to be disconnected from some workspaces.")],
        leaving_team_ids: Annotated[Optional[StrictStr], Field(description="The team to be removed from the channel. Currently only a single team id can be specified.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> AdminConversationsRenameSchema:
        """admin_conversations_disconnect_shared

        Disconnect a connected channel from one or more workspaces.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to be disconnected from some workspaces. (required)
        :type channel_id: str
        :param leaving_team_ids: The team to be removed from the channel. Currently only a single team id can be specified.
        :type leaving_team_ids: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_disconnect_shared_serialize(
            token=token,
            channel_id=channel_id,
            leaving_team_ids=leaving_team_ids,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsRenameSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_conversations_disconnect_shared_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to be disconnected from some workspaces.")],
        leaving_team_ids: Annotated[Optional[StrictStr], Field(description="The team to be removed from the channel. Currently only a single team id can be specified.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[AdminConversationsRenameSchema]:
        """admin_conversations_disconnect_shared

        Disconnect a connected channel from one or more workspaces.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to be disconnected from some workspaces. (required)
        :type channel_id: str
        :param leaving_team_ids: The team to be removed from the channel. Currently only a single team id can be specified.
        :type leaving_team_ids: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_disconnect_shared_serialize(
            token=token,
            channel_id=channel_id,
            leaving_team_ids=leaving_team_ids,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsRenameSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_conversations_disconnect_shared_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to be disconnected from some workspaces.")],
        leaving_team_ids: Annotated[Optional[StrictStr], Field(description="The team to be removed from the channel. Currently only a single team id can be specified.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_conversations_disconnect_shared

        Disconnect a connected channel from one or more workspaces.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to be disconnected from some workspaces. (required)
        :type channel_id: str
        :param leaving_team_ids: The team to be removed from the channel. Currently only a single team id can be specified.
        :type leaving_team_ids: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_disconnect_shared_serialize(
            token=token,
            channel_id=channel_id,
            leaving_team_ids=leaving_team_ids,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsRenameSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_conversations_disconnect_shared_serialize(
        self,
        token,
        channel_id,
        leaving_team_ids,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if channel_id is not None:
            _form_params.append(('channel_id', channel_id))
        if leaving_team_ids is not None:
            _form_params.append(('leaving_team_ids', leaving_team_ids))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.conversations.disconnectShared',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_conversations_get_conversation_prefs(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:read`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to get preferences for.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> AdminConversationsGetConversationPrefsSchema:
        """admin_conversations_get_conversation_prefs

        Get conversation preferences for a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:read` (required)
        :type token: str
        :param channel_id: The channel to get preferences for. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_get_conversation_prefs_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsGetConversationPrefsSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_conversations_get_conversation_prefs_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:read`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to get preferences for.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[AdminConversationsGetConversationPrefsSchema]:
        """admin_conversations_get_conversation_prefs

        Get conversation preferences for a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:read` (required)
        :type token: str
        :param channel_id: The channel to get preferences for. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_get_conversation_prefs_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsGetConversationPrefsSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_conversations_get_conversation_prefs_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:read`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to get preferences for.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_conversations_get_conversation_prefs

        Get conversation preferences for a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:read` (required)
        :type token: str
        :param channel_id: The channel to get preferences for. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_get_conversation_prefs_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsGetConversationPrefsSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_conversations_get_conversation_prefs_serialize(
        self,
        token,
        channel_id,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if channel_id is not None:
            
            _query_params.append(('channel_id', channel_id))
            
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/admin.conversations.getConversationPrefs',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_conversations_get_teams(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:read`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to determine connected workspaces within the organization for.")],
        cursor: Annotated[Optional[StrictStr], Field(description="Set `cursor` to `next_cursor` returned by the previous call to list items in the next page")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of items to return. Must be between 1 - 1000 both inclusive.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> AdminConversationsGetTeamsSchema:
        """admin_conversations_get_teams

        Get all the workspaces a given public or private channel is connected to within this Enterprise org.

        :param token: Authentication token. Requires scope: `admin.conversations:read` (required)
        :type token: str
        :param channel_id: The channel to determine connected workspaces within the organization for. (required)
        :type channel_id: str
        :param cursor: Set `cursor` to `next_cursor` returned by the previous call to list items in the next page
        :type cursor: str
        :param limit: The maximum number of items to return. Must be between 1 - 1000 both inclusive.
        :type limit: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_get_teams_serialize(
            token=token,
            channel_id=channel_id,
            cursor=cursor,
            limit=limit,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsGetTeamsSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_conversations_get_teams_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:read`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to determine connected workspaces within the organization for.")],
        cursor: Annotated[Optional[StrictStr], Field(description="Set `cursor` to `next_cursor` returned by the previous call to list items in the next page")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of items to return. Must be between 1 - 1000 both inclusive.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[AdminConversationsGetTeamsSchema]:
        """admin_conversations_get_teams

        Get all the workspaces a given public or private channel is connected to within this Enterprise org.

        :param token: Authentication token. Requires scope: `admin.conversations:read` (required)
        :type token: str
        :param channel_id: The channel to determine connected workspaces within the organization for. (required)
        :type channel_id: str
        :param cursor: Set `cursor` to `next_cursor` returned by the previous call to list items in the next page
        :type cursor: str
        :param limit: The maximum number of items to return. Must be between 1 - 1000 both inclusive.
        :type limit: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_get_teams_serialize(
            token=token,
            channel_id=channel_id,
            cursor=cursor,
            limit=limit,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsGetTeamsSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_conversations_get_teams_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:read`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to determine connected workspaces within the organization for.")],
        cursor: Annotated[Optional[StrictStr], Field(description="Set `cursor` to `next_cursor` returned by the previous call to list items in the next page")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="The maximum number of items to return. Must be between 1 - 1000 both inclusive.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_conversations_get_teams

        Get all the workspaces a given public or private channel is connected to within this Enterprise org.

        :param token: Authentication token. Requires scope: `admin.conversations:read` (required)
        :type token: str
        :param channel_id: The channel to determine connected workspaces within the organization for. (required)
        :type channel_id: str
        :param cursor: Set `cursor` to `next_cursor` returned by the previous call to list items in the next page
        :type cursor: str
        :param limit: The maximum number of items to return. Must be between 1 - 1000 both inclusive.
        :type limit: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_get_teams_serialize(
            token=token,
            channel_id=channel_id,
            cursor=cursor,
            limit=limit,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsGetTeamsSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_conversations_get_teams_serialize(
        self,
        token,
        channel_id,
        cursor,
        limit,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if channel_id is not None:
            
            _query_params.append(('channel_id', channel_id))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/admin.conversations.getTeams',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_conversations_invite(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        user_ids: Annotated[StrictStr, Field(description="The users to invite.")],
        channel_id: Annotated[StrictStr, Field(description="The channel that the users will be invited to.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> AdminConversationsInviteSchema:
        """admin_conversations_invite

        Invite a user to a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param user_ids: The users to invite. (required)
        :type user_ids: str
        :param channel_id: The channel that the users will be invited to. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_invite_serialize(
            token=token,
            user_ids=user_ids,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsInviteSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_conversations_invite_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        user_ids: Annotated[StrictStr, Field(description="The users to invite.")],
        channel_id: Annotated[StrictStr, Field(description="The channel that the users will be invited to.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[AdminConversationsInviteSchema]:
        """admin_conversations_invite

        Invite a user to a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param user_ids: The users to invite. (required)
        :type user_ids: str
        :param channel_id: The channel that the users will be invited to. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_invite_serialize(
            token=token,
            user_ids=user_ids,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsInviteSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_conversations_invite_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        user_ids: Annotated[StrictStr, Field(description="The users to invite.")],
        channel_id: Annotated[StrictStr, Field(description="The channel that the users will be invited to.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_conversations_invite

        Invite a user to a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param user_ids: The users to invite. (required)
        :type user_ids: str
        :param channel_id: The channel that the users will be invited to. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_invite_serialize(
            token=token,
            user_ids=user_ids,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsInviteSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_conversations_invite_serialize(
        self,
        token,
        user_ids,
        channel_id,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if user_ids is not None:
            _form_params.append(('user_ids', user_ids))
        if channel_id is not None:
            _form_params.append(('channel_id', channel_id))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.conversations.invite',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_conversations_rename(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to rename.")],
        name: StrictStr,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> AdminConversationsRenameSchema1:
        """admin_conversations_rename

        Rename a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to rename. (required)
        :type channel_id: str
        :param name: (required)
        :type name: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_rename_serialize(
            token=token,
            channel_id=channel_id,
            name=name,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsRenameSchema1",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_conversations_rename_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to rename.")],
        name: StrictStr,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[AdminConversationsRenameSchema1]:
        """admin_conversations_rename

        Rename a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to rename. (required)
        :type channel_id: str
        :param name: (required)
        :type name: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_rename_serialize(
            token=token,
            channel_id=channel_id,
            name=name,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsRenameSchema1",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_conversations_rename_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to rename.")],
        name: StrictStr,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_conversations_rename

        Rename a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to rename. (required)
        :type channel_id: str
        :param name: (required)
        :type name: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_rename_serialize(
            token=token,
            channel_id=channel_id,
            name=name,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsRenameSchema1",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_conversations_rename_serialize(
        self,
        token,
        channel_id,
        name,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if channel_id is not None:
            _form_params.append(('channel_id', channel_id))
        if name is not None:
            _form_params.append(('name', name))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.conversations.rename',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_conversations_search(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:read`")],
        team_ids: Annotated[Optional[StrictStr], Field(description="Comma separated string of team IDs, signifying the workspaces to search through.")] = None,
        query: Annotated[Optional[StrictStr], Field(description="Name of the the channel to query by.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum number of items to be returned. Must be between 1 - 20 both inclusive. Default is 10.")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Set `cursor` to `next_cursor` returned by the previous call to list items in the next page.")] = None,
        search_channel_types: Annotated[Optional[StrictStr], Field(description="The type of channel to include or exclude in the search. For example `private` will search private channels, while `private_exclude` will exclude them. For a full list of types, check the [Types section](#types).")] = None,
        sort: Annotated[Optional[StrictStr], Field(description="Possible values are `relevant` (search ranking based on what we think is closest), `name` (alphabetical), `member_count` (number of users in the channel), and `created` (date channel was created). You can optionally pair this with the `sort_dir` arg to change how it is sorted ")] = None,
        sort_dir: Annotated[Optional[StrictStr], Field(description="Sort direction. Possible values are `asc` for ascending order like (1, 2, 3) or (a, b, c), and `desc` for descending order like (3, 2, 1) or (c, b, a)")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> AdminConversationsSearchSchema:
        """admin_conversations_search

        Search for public or private channels in an Enterprise organization.

        :param token: Authentication token. Requires scope: `admin.conversations:read` (required)
        :type token: str
        :param team_ids: Comma separated string of team IDs, signifying the workspaces to search through.
        :type team_ids: str
        :param query: Name of the the channel to query by.
        :type query: str
        :param limit: Maximum number of items to be returned. Must be between 1 - 20 both inclusive. Default is 10.
        :type limit: int
        :param cursor: Set `cursor` to `next_cursor` returned by the previous call to list items in the next page.
        :type cursor: str
        :param search_channel_types: The type of channel to include or exclude in the search. For example `private` will search private channels, while `private_exclude` will exclude them. For a full list of types, check the [Types section](#types).
        :type search_channel_types: str
        :param sort: Possible values are `relevant` (search ranking based on what we think is closest), `name` (alphabetical), `member_count` (number of users in the channel), and `created` (date channel was created). You can optionally pair this with the `sort_dir` arg to change how it is sorted 
        :type sort: str
        :param sort_dir: Sort direction. Possible values are `asc` for ascending order like (1, 2, 3) or (a, b, c), and `desc` for descending order like (3, 2, 1) or (c, b, a)
        :type sort_dir: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_search_serialize(
            token=token,
            team_ids=team_ids,
            query=query,
            limit=limit,
            cursor=cursor,
            search_channel_types=search_channel_types,
            sort=sort,
            sort_dir=sort_dir,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsSearchSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_conversations_search_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:read`")],
        team_ids: Annotated[Optional[StrictStr], Field(description="Comma separated string of team IDs, signifying the workspaces to search through.")] = None,
        query: Annotated[Optional[StrictStr], Field(description="Name of the the channel to query by.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum number of items to be returned. Must be between 1 - 20 both inclusive. Default is 10.")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Set `cursor` to `next_cursor` returned by the previous call to list items in the next page.")] = None,
        search_channel_types: Annotated[Optional[StrictStr], Field(description="The type of channel to include or exclude in the search. For example `private` will search private channels, while `private_exclude` will exclude them. For a full list of types, check the [Types section](#types).")] = None,
        sort: Annotated[Optional[StrictStr], Field(description="Possible values are `relevant` (search ranking based on what we think is closest), `name` (alphabetical), `member_count` (number of users in the channel), and `created` (date channel was created). You can optionally pair this with the `sort_dir` arg to change how it is sorted ")] = None,
        sort_dir: Annotated[Optional[StrictStr], Field(description="Sort direction. Possible values are `asc` for ascending order like (1, 2, 3) or (a, b, c), and `desc` for descending order like (3, 2, 1) or (c, b, a)")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[AdminConversationsSearchSchema]:
        """admin_conversations_search

        Search for public or private channels in an Enterprise organization.

        :param token: Authentication token. Requires scope: `admin.conversations:read` (required)
        :type token: str
        :param team_ids: Comma separated string of team IDs, signifying the workspaces to search through.
        :type team_ids: str
        :param query: Name of the the channel to query by.
        :type query: str
        :param limit: Maximum number of items to be returned. Must be between 1 - 20 both inclusive. Default is 10.
        :type limit: int
        :param cursor: Set `cursor` to `next_cursor` returned by the previous call to list items in the next page.
        :type cursor: str
        :param search_channel_types: The type of channel to include or exclude in the search. For example `private` will search private channels, while `private_exclude` will exclude them. For a full list of types, check the [Types section](#types).
        :type search_channel_types: str
        :param sort: Possible values are `relevant` (search ranking based on what we think is closest), `name` (alphabetical), `member_count` (number of users in the channel), and `created` (date channel was created). You can optionally pair this with the `sort_dir` arg to change how it is sorted 
        :type sort: str
        :param sort_dir: Sort direction. Possible values are `asc` for ascending order like (1, 2, 3) or (a, b, c), and `desc` for descending order like (3, 2, 1) or (c, b, a)
        :type sort_dir: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_search_serialize(
            token=token,
            team_ids=team_ids,
            query=query,
            limit=limit,
            cursor=cursor,
            search_channel_types=search_channel_types,
            sort=sort,
            sort_dir=sort_dir,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsSearchSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_conversations_search_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:read`")],
        team_ids: Annotated[Optional[StrictStr], Field(description="Comma separated string of team IDs, signifying the workspaces to search through.")] = None,
        query: Annotated[Optional[StrictStr], Field(description="Name of the the channel to query by.")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Maximum number of items to be returned. Must be between 1 - 20 both inclusive. Default is 10.")] = None,
        cursor: Annotated[Optional[StrictStr], Field(description="Set `cursor` to `next_cursor` returned by the previous call to list items in the next page.")] = None,
        search_channel_types: Annotated[Optional[StrictStr], Field(description="The type of channel to include or exclude in the search. For example `private` will search private channels, while `private_exclude` will exclude them. For a full list of types, check the [Types section](#types).")] = None,
        sort: Annotated[Optional[StrictStr], Field(description="Possible values are `relevant` (search ranking based on what we think is closest), `name` (alphabetical), `member_count` (number of users in the channel), and `created` (date channel was created). You can optionally pair this with the `sort_dir` arg to change how it is sorted ")] = None,
        sort_dir: Annotated[Optional[StrictStr], Field(description="Sort direction. Possible values are `asc` for ascending order like (1, 2, 3) or (a, b, c), and `desc` for descending order like (3, 2, 1) or (c, b, a)")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_conversations_search

        Search for public or private channels in an Enterprise organization.

        :param token: Authentication token. Requires scope: `admin.conversations:read` (required)
        :type token: str
        :param team_ids: Comma separated string of team IDs, signifying the workspaces to search through.
        :type team_ids: str
        :param query: Name of the the channel to query by.
        :type query: str
        :param limit: Maximum number of items to be returned. Must be between 1 - 20 both inclusive. Default is 10.
        :type limit: int
        :param cursor: Set `cursor` to `next_cursor` returned by the previous call to list items in the next page.
        :type cursor: str
        :param search_channel_types: The type of channel to include or exclude in the search. For example `private` will search private channels, while `private_exclude` will exclude them. For a full list of types, check the [Types section](#types).
        :type search_channel_types: str
        :param sort: Possible values are `relevant` (search ranking based on what we think is closest), `name` (alphabetical), `member_count` (number of users in the channel), and `created` (date channel was created). You can optionally pair this with the `sort_dir` arg to change how it is sorted 
        :type sort: str
        :param sort_dir: Sort direction. Possible values are `asc` for ascending order like (1, 2, 3) or (a, b, c), and `desc` for descending order like (3, 2, 1) or (c, b, a)
        :type sort_dir: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_search_serialize(
            token=token,
            team_ids=team_ids,
            query=query,
            limit=limit,
            cursor=cursor,
            search_channel_types=search_channel_types,
            sort=sort,
            sort_dir=sort_dir,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsSearchSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_conversations_search_serialize(
        self,
        token,
        team_ids,
        query,
        limit,
        cursor,
        search_channel_types,
        sort,
        sort_dir,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if team_ids is not None:
            
            _query_params.append(('team_ids', team_ids))
            
        if query is not None:
            
            _query_params.append(('query', query))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if cursor is not None:
            
            _query_params.append(('cursor', cursor))
            
        if search_channel_types is not None:
            
            _query_params.append(('search_channel_types', search_channel_types))
            
        if sort is not None:
            
            _query_params.append(('sort', sort))
            
        if sort_dir is not None:
            
            _query_params.append(('sort_dir', sort_dir))
            
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/admin.conversations.search',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_conversations_set_conversation_prefs(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to set the prefs for")],
        prefs: Annotated[StrictStr, Field(description="The prefs for this channel in a stringified JSON format.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> AdminConversationsSetConversationPrefsSchema:
        """admin_conversations_set_conversation_prefs

        Set the posting permissions for a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to set the prefs for (required)
        :type channel_id: str
        :param prefs: The prefs for this channel in a stringified JSON format. (required)
        :type prefs: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_set_conversation_prefs_serialize(
            token=token,
            channel_id=channel_id,
            prefs=prefs,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsSetConversationPrefsSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_conversations_set_conversation_prefs_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to set the prefs for")],
        prefs: Annotated[StrictStr, Field(description="The prefs for this channel in a stringified JSON format.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[AdminConversationsSetConversationPrefsSchema]:
        """admin_conversations_set_conversation_prefs

        Set the posting permissions for a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to set the prefs for (required)
        :type channel_id: str
        :param prefs: The prefs for this channel in a stringified JSON format. (required)
        :type prefs: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_set_conversation_prefs_serialize(
            token=token,
            channel_id=channel_id,
            prefs=prefs,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsSetConversationPrefsSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_conversations_set_conversation_prefs_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to set the prefs for")],
        prefs: Annotated[StrictStr, Field(description="The prefs for this channel in a stringified JSON format.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_conversations_set_conversation_prefs

        Set the posting permissions for a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to set the prefs for (required)
        :type channel_id: str
        :param prefs: The prefs for this channel in a stringified JSON format. (required)
        :type prefs: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_set_conversation_prefs_serialize(
            token=token,
            channel_id=channel_id,
            prefs=prefs,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsSetConversationPrefsSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_conversations_set_conversation_prefs_serialize(
        self,
        token,
        channel_id,
        prefs,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if channel_id is not None:
            _form_params.append(('channel_id', channel_id))
        if prefs is not None:
            _form_params.append(('prefs', prefs))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.conversations.setConversationPrefs',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_conversations_set_teams(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The encoded `channel_id` to add or remove to workspaces.")],
        team_id: Annotated[Optional[StrictStr], Field(description="The workspace to which the channel belongs. Omit this argument if the channel is a cross-workspace shared channel.")] = None,
        target_team_ids: Annotated[Optional[StrictStr], Field(description="A comma-separated list of workspaces to which the channel should be shared. Not required if the channel is being shared org-wide.")] = None,
        org_channel: Annotated[Optional[StrictBool], Field(description="True if channel has to be converted to an org channel")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> DefaultSuccessTemplate:
        """admin_conversations_set_teams

        Set the workspaces in an Enterprise grid org that connect to a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The encoded `channel_id` to add or remove to workspaces. (required)
        :type channel_id: str
        :param team_id: The workspace to which the channel belongs. Omit this argument if the channel is a cross-workspace shared channel.
        :type team_id: str
        :param target_team_ids: A comma-separated list of workspaces to which the channel should be shared. Not required if the channel is being shared org-wide.
        :type target_team_ids: str
        :param org_channel: True if channel has to be converted to an org channel
        :type org_channel: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_set_teams_serialize(
            token=token,
            channel_id=channel_id,
            team_id=team_id,
            target_team_ids=target_team_ids,
            org_channel=org_channel,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_conversations_set_teams_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The encoded `channel_id` to add or remove to workspaces.")],
        team_id: Annotated[Optional[StrictStr], Field(description="The workspace to which the channel belongs. Omit this argument if the channel is a cross-workspace shared channel.")] = None,
        target_team_ids: Annotated[Optional[StrictStr], Field(description="A comma-separated list of workspaces to which the channel should be shared. Not required if the channel is being shared org-wide.")] = None,
        org_channel: Annotated[Optional[StrictBool], Field(description="True if channel has to be converted to an org channel")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[DefaultSuccessTemplate]:
        """admin_conversations_set_teams

        Set the workspaces in an Enterprise grid org that connect to a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The encoded `channel_id` to add or remove to workspaces. (required)
        :type channel_id: str
        :param team_id: The workspace to which the channel belongs. Omit this argument if the channel is a cross-workspace shared channel.
        :type team_id: str
        :param target_team_ids: A comma-separated list of workspaces to which the channel should be shared. Not required if the channel is being shared org-wide.
        :type target_team_ids: str
        :param org_channel: True if channel has to be converted to an org channel
        :type org_channel: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_set_teams_serialize(
            token=token,
            channel_id=channel_id,
            team_id=team_id,
            target_team_ids=target_team_ids,
            org_channel=org_channel,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_conversations_set_teams_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The encoded `channel_id` to add or remove to workspaces.")],
        team_id: Annotated[Optional[StrictStr], Field(description="The workspace to which the channel belongs. Omit this argument if the channel is a cross-workspace shared channel.")] = None,
        target_team_ids: Annotated[Optional[StrictStr], Field(description="A comma-separated list of workspaces to which the channel should be shared. Not required if the channel is being shared org-wide.")] = None,
        org_channel: Annotated[Optional[StrictBool], Field(description="True if channel has to be converted to an org channel")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_conversations_set_teams

        Set the workspaces in an Enterprise grid org that connect to a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The encoded `channel_id` to add or remove to workspaces. (required)
        :type channel_id: str
        :param team_id: The workspace to which the channel belongs. Omit this argument if the channel is a cross-workspace shared channel.
        :type team_id: str
        :param target_team_ids: A comma-separated list of workspaces to which the channel should be shared. Not required if the channel is being shared org-wide.
        :type target_team_ids: str
        :param org_channel: True if channel has to be converted to an org channel
        :type org_channel: bool
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_set_teams_serialize(
            token=token,
            channel_id=channel_id,
            team_id=team_id,
            target_team_ids=target_team_ids,
            org_channel=org_channel,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "DefaultSuccessTemplate",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_conversations_set_teams_serialize(
        self,
        token,
        channel_id,
        team_id,
        target_team_ids,
        org_channel,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if channel_id is not None:
            _form_params.append(('channel_id', channel_id))
        if team_id is not None:
            _form_params.append(('team_id', team_id))
        if target_team_ids is not None:
            _form_params.append(('target_team_ids', target_team_ids))
        if org_channel is not None:
            _form_params.append(('org_channel', org_channel))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.conversations.setTeams',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def admin_conversations_unarchive(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to unarchive.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> AdminConversationsUnarchiveSchema:
        """admin_conversations_unarchive

        Unarchive a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to unarchive. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_unarchive_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsUnarchiveSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def admin_conversations_unarchive_with_http_info(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to unarchive.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[AdminConversationsUnarchiveSchema]:
        """admin_conversations_unarchive

        Unarchive a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to unarchive. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_unarchive_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsUnarchiveSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def admin_conversations_unarchive_without_preload_content(
        self,
        token: Annotated[StrictStr, Field(description="Authentication token. Requires scope: `admin.conversations:write`")],
        channel_id: Annotated[StrictStr, Field(description="The channel to unarchive.")],
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """admin_conversations_unarchive

        Unarchive a public or private channel.

        :param token: Authentication token. Requires scope: `admin.conversations:write` (required)
        :type token: str
        :param channel_id: The channel to unarchive. (required)
        :type channel_id: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._admin_conversations_unarchive_serialize(
            token=token,
            channel_id=channel_id,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AdminConversationsUnarchiveSchema",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _admin_conversations_unarchive_serialize(
        self,
        token,
        channel_id,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        if token is not None:
            _header_params['token'] = token
        # process the form parameters
        if channel_id is not None:
            _form_params.append(('channel_id', channel_id))
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/x-www-form-urlencoded', 
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'slackAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/admin.conversations.unarchive',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )





# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.admin_conversations_search_schema import AdminConversationsSearchSchema

class TestAdminConversationsSearchSchema(unittest.TestCase):
    """AdminConversationsSearchSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AdminConversationsSearchSchema:
        """Test AdminConversationsSearchSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AdminConversationsSearchSchema`
        """
        model = AdminConversationsSearchSchema()
        if include_optional:
            return AdminConversationsSearchSchema(
                channels = [
                    slack_beta_ti.models.channel_object.Channel Object(
                        accepted_user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        created = 56, 
                        creator = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        id = 'CQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        is_archived = True, 
                        is_channel = True, 
                        is_frozen = True, 
                        is_general = True, 
                        is_member = True, 
                        is_moved = 56, 
                        is_mpim = True, 
                        is_non_threadable = True, 
                        is_org_shared = True, 
                        is_pending_ext_shared = True, 
                        is_private = True, 
                        is_read_only = True, 
                        is_shared = True, 
                        is_thread_only = True, 
                        last_read = '0480728880.015280', 
                        latest = slack_beta_ti.models.latest.latest(), 
                        members = [
                            'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                            ], 
                        name = '', 
                        name_normalized = '', 
                        num_members = 56, 
                        pending_shared = [
                            'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                            ], 
                        previous_names = [
                            ''
                            ], 
                        priority = 1.337, 
                        purpose = slack_beta_ti.models.purpose.purpose(), 
                        topic = slack_beta_ti.models.topic.topic(), 
                        unlinked = 56, 
                        unread_count = 56, 
                        unread_count_display = 56, )
                    ],
                next_cursor = ''
            )
        else:
            return AdminConversationsSearchSchema(
                channels = [
                    slack_beta_ti.models.channel_object.Channel Object(
                        accepted_user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        created = 56, 
                        creator = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        id = 'CQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        is_archived = True, 
                        is_channel = True, 
                        is_frozen = True, 
                        is_general = True, 
                        is_member = True, 
                        is_moved = 56, 
                        is_mpim = True, 
                        is_non_threadable = True, 
                        is_org_shared = True, 
                        is_pending_ext_shared = True, 
                        is_private = True, 
                        is_read_only = True, 
                        is_shared = True, 
                        is_thread_only = True, 
                        last_read = '0480728880.015280', 
                        latest = slack_beta_ti.models.latest.latest(), 
                        members = [
                            'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                            ], 
                        name = '', 
                        name_normalized = '', 
                        num_members = 56, 
                        pending_shared = [
                            'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                            ], 
                        previous_names = [
                            ''
                            ], 
                        priority = 1.337, 
                        purpose = slack_beta_ti.models.purpose.purpose(), 
                        topic = slack_beta_ti.models.topic.topic(), 
                        unlinked = 56, 
                        unread_count = 56, 
                        unread_count_display = 56, )
                    ],
                next_cursor = '',
        )
        """

    def testAdminConversationsSearchSchema(self):
        """Test AdminConversationsSearchSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from slack_beta_ti.models.objs_reaction import ObjsReaction
from typing import Optional, Set
from typing_extensions import Self

class ObjsFile(BaseModel):
    """
    ObjsFile
    """ # noqa: E501
    channels: Optional[List[Annotated[str, Field(strict=True)]]] = None
    comments_count: Optional[StrictInt] = None
    created: Optional[StrictInt] = None
    date_delete: Optional[StrictInt] = None
    display_as_bot: Optional[StrictBool] = None
    editable: Optional[StrictBool] = None
    editor: Optional[Annotated[str, Field(strict=True)]] = None
    external_id: Optional[StrictStr] = None
    external_type: Optional[StrictStr] = None
    external_url: Optional[StrictStr] = None
    filetype: Optional[StrictStr] = None
    groups: Optional[List[Annotated[str, Field(strict=True)]]] = None
    has_rich_preview: Optional[StrictBool] = None
    id: Optional[Annotated[str, Field(strict=True)]] = None
    image_exif_rotation: Optional[StrictInt] = None
    ims: Optional[List[Annotated[str, Field(strict=True)]]] = None
    is_external: Optional[StrictBool] = None
    is_public: Optional[StrictBool] = None
    is_starred: Optional[StrictBool] = None
    is_tombstoned: Optional[StrictBool] = None
    last_editor: Optional[Annotated[str, Field(strict=True)]] = None
    mimetype: Optional[StrictStr] = None
    mode: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    non_owner_editable: Optional[StrictBool] = None
    num_stars: Optional[StrictInt] = None
    original_h: Optional[StrictInt] = None
    original_w: Optional[StrictInt] = None
    permalink: Optional[StrictStr] = None
    permalink_public: Optional[StrictStr] = None
    pinned_info: Optional[Dict[str, Any]] = None
    pinned_to: Optional[List[Annotated[str, Field(strict=True)]]] = None
    pretty_type: Optional[StrictStr] = None
    preview: Optional[StrictStr] = None
    public_url_shared: Optional[StrictBool] = None
    reactions: Optional[List[ObjsReaction]] = None
    shares: Optional[Dict[str, Any]] = None
    size: Optional[StrictInt] = None
    source_team: Optional[Annotated[str, Field(strict=True)]] = None
    state: Optional[StrictStr] = None
    thumb_1024: Optional[StrictStr] = None
    thumb_1024_h: Optional[StrictInt] = None
    thumb_1024_w: Optional[StrictInt] = None
    thumb_160: Optional[StrictStr] = None
    thumb_360: Optional[StrictStr] = None
    thumb_360_h: Optional[StrictInt] = None
    thumb_360_w: Optional[StrictInt] = None
    thumb_480: Optional[StrictStr] = None
    thumb_480_h: Optional[StrictInt] = None
    thumb_480_w: Optional[StrictInt] = None
    thumb_64: Optional[StrictStr] = None
    thumb_720: Optional[StrictStr] = None
    thumb_720_h: Optional[StrictInt] = None
    thumb_720_w: Optional[StrictInt] = None
    thumb_80: Optional[StrictStr] = None
    thumb_800: Optional[StrictStr] = None
    thumb_800_h: Optional[StrictInt] = None
    thumb_800_w: Optional[StrictInt] = None
    thumb_960: Optional[StrictStr] = None
    thumb_960_h: Optional[StrictInt] = None
    thumb_960_w: Optional[StrictInt] = None
    thumb_tiny: Optional[StrictStr] = None
    timestamp: Optional[StrictInt] = None
    title: Optional[StrictStr] = None
    updated: Optional[StrictInt] = None
    url_private: Optional[StrictStr] = None
    url_private_download: Optional[StrictStr] = None
    user: Optional[StrictStr] = None
    user_team: Optional[Annotated[str, Field(strict=True)]] = None
    username: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["channels", "comments_count", "created", "date_delete", "display_as_bot", "editable", "editor", "external_id", "external_type", "external_url", "filetype", "groups", "has_rich_preview", "id", "image_exif_rotation", "ims", "is_external", "is_public", "is_starred", "is_tombstoned", "last_editor", "mimetype", "mode", "name", "non_owner_editable", "num_stars", "original_h", "original_w", "permalink", "permalink_public", "pinned_info", "pinned_to", "pretty_type", "preview", "public_url_shared", "reactions", "shares", "size", "source_team", "state", "thumb_1024", "thumb_1024_h", "thumb_1024_w", "thumb_160", "thumb_360", "thumb_360_h", "thumb_360_w", "thumb_480", "thumb_480_h", "thumb_480_w", "thumb_64", "thumb_720", "thumb_720_h", "thumb_720_w", "thumb_80", "thumb_800", "thumb_800_h", "thumb_800_w", "thumb_960", "thumb_960_h", "thumb_960_w", "thumb_tiny", "timestamp", "title", "updated", "url_private", "url_private_download", "user", "user_team", "username"]

    @field_validator('editor')
    def editor_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[UW][A-Z0-9]{2,}$", value):
            raise ValueError(r"must validate the regular expression /^[UW][A-Z0-9]{2,}$/")
        return value

    @field_validator('id')
    def id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[F][A-Z0-9]{8,}$", value):
            raise ValueError(r"must validate the regular expression /^[F][A-Z0-9]{8,}$/")
        return value

    @field_validator('last_editor')
    def last_editor_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[UW][A-Z0-9]{2,}$", value):
            raise ValueError(r"must validate the regular expression /^[UW][A-Z0-9]{2,}$/")
        return value

    @field_validator('source_team')
    def source_team_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[T][A-Z0-9]{2,}$", value):
            raise ValueError(r"must validate the regular expression /^[T][A-Z0-9]{2,}$/")
        return value

    @field_validator('user_team')
    def user_team_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[T][A-Z0-9]{2,}$", value):
            raise ValueError(r"must validate the regular expression /^[T][A-Z0-9]{2,}$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ObjsFile from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in reactions (list)
        _items = []
        if self.reactions:
            for _item_reactions in self.reactions:
                if _item_reactions:
                    _items.append(_item_reactions.to_dict())
            _dict['reactions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ObjsFile from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "channels": obj.get("channels"),
            "comments_count": obj.get("comments_count"),
            "created": obj.get("created"),
            "date_delete": obj.get("date_delete"),
            "display_as_bot": obj.get("display_as_bot"),
            "editable": obj.get("editable"),
            "editor": obj.get("editor"),
            "external_id": obj.get("external_id"),
            "external_type": obj.get("external_type"),
            "external_url": obj.get("external_url"),
            "filetype": obj.get("filetype"),
            "groups": obj.get("groups"),
            "has_rich_preview": obj.get("has_rich_preview"),
            "id": obj.get("id"),
            "image_exif_rotation": obj.get("image_exif_rotation"),
            "ims": obj.get("ims"),
            "is_external": obj.get("is_external"),
            "is_public": obj.get("is_public"),
            "is_starred": obj.get("is_starred"),
            "is_tombstoned": obj.get("is_tombstoned"),
            "last_editor": obj.get("last_editor"),
            "mimetype": obj.get("mimetype"),
            "mode": obj.get("mode"),
            "name": obj.get("name"),
            "non_owner_editable": obj.get("non_owner_editable"),
            "num_stars": obj.get("num_stars"),
            "original_h": obj.get("original_h"),
            "original_w": obj.get("original_w"),
            "permalink": obj.get("permalink"),
            "permalink_public": obj.get("permalink_public"),
            "pinned_info": obj.get("pinned_info"),
            "pinned_to": obj.get("pinned_to"),
            "pretty_type": obj.get("pretty_type"),
            "preview": obj.get("preview"),
            "public_url_shared": obj.get("public_url_shared"),
            "reactions": [ObjsReaction.from_dict(_item) for _item in obj["reactions"]] if obj.get("reactions") is not None else None,
            "shares": obj.get("shares"),
            "size": obj.get("size"),
            "source_team": obj.get("source_team"),
            "state": obj.get("state"),
            "thumb_1024": obj.get("thumb_1024"),
            "thumb_1024_h": obj.get("thumb_1024_h"),
            "thumb_1024_w": obj.get("thumb_1024_w"),
            "thumb_160": obj.get("thumb_160"),
            "thumb_360": obj.get("thumb_360"),
            "thumb_360_h": obj.get("thumb_360_h"),
            "thumb_360_w": obj.get("thumb_360_w"),
            "thumb_480": obj.get("thumb_480"),
            "thumb_480_h": obj.get("thumb_480_h"),
            "thumb_480_w": obj.get("thumb_480_w"),
            "thumb_64": obj.get("thumb_64"),
            "thumb_720": obj.get("thumb_720"),
            "thumb_720_h": obj.get("thumb_720_h"),
            "thumb_720_w": obj.get("thumb_720_w"),
            "thumb_80": obj.get("thumb_80"),
            "thumb_800": obj.get("thumb_800"),
            "thumb_800_h": obj.get("thumb_800_h"),
            "thumb_800_w": obj.get("thumb_800_w"),
            "thumb_960": obj.get("thumb_960"),
            "thumb_960_h": obj.get("thumb_960_h"),
            "thumb_960_w": obj.get("thumb_960_w"),
            "thumb_tiny": obj.get("thumb_tiny"),
            "timestamp": obj.get("timestamp"),
            "title": obj.get("title"),
            "updated": obj.get("updated"),
            "url_private": obj.get("url_private"),
            "url_private_download": obj.get("url_private_download"),
            "user": obj.get("user"),
            "user_team": obj.get("user_team"),
            "username": obj.get("username")
        })
        return _obj





# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.reactions_list_schema import ReactionsListSchema

class TestReactionsListSchema(unittest.TestCase):
    """ReactionsListSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReactionsListSchema:
        """Test ReactionsListSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReactionsListSchema`
        """
        model = ReactionsListSchema()
        if include_optional:
            return ReactionsListSchema(
                items = [
                    None
                    ],
                ok = True,
                paging = slack_beta_ti.models.paging_object.paging object(
                    count = 56, 
                    page = 56, 
                    pages = 56, 
                    per_page = 56, 
                    spill = 56, 
                    total = 56, ),
                response_metadata = [
                    ''
                    ]
            )
        else:
            return ReactionsListSchema(
                items = [
                    None
                    ],
                ok = True,
        )
        """

    def testReactionsListSchema(self):
        """Test ReactionsListSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.objs_message import ObjsMessage

class TestObjsMessage(unittest.TestCase):
    """ObjsMessage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ObjsMessage:
        """Test ObjsMessage
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ObjsMessage`
        """
        model = ObjsMessage()
        if include_optional:
            return ObjsMessage(
                attachments = [
                    None
                    ],
                blocks = [
                    None
                    ],
                bot_id = None,
                bot_profile = slack_beta_ti.models.bot_profile_object.Bot Profile Object(
                    app_id = 'A8', 
                    deleted = True, 
                    icons = slack_beta_ti.models.icons.icons(), 
                    id = 'B8Q6ZGCKEC0L3O4GI7XH', 
                    name = '', 
                    team_id = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    updated = 56, ),
                client_msg_id = '',
                comment = slack_beta_ti.models.file_comment_object.File Comment Object(
                    comment = '', 
                    created = 56, 
                    id = 'Fc8Q6ZGCKEC0L3O4GI7XH', 
                    is_intro = True, 
                    is_starred = True, 
                    num_stars = 56, 
                    pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                    pinned_to = [
                        'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                        ], 
                    reactions = [
                        slack_beta_ti.models.reaction_object.Reaction object(
                            count = 56, 
                            name = '', 
                            users = [
                                'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                                ], )
                        ], 
                    timestamp = 56, 
                    user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', ),
                display_as_bot = True,
                file = slack_beta_ti.models.file_object.file object(
                    channels = [
                        'CQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                        ], 
                    comments_count = 56, 
                    created = 56, 
                    date_delete = 56, 
                    display_as_bot = True, 
                    editable = True, 
                    editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    external_id = '', 
                    external_type = '', 
                    external_url = '', 
                    filetype = '', 
                    groups = [
                        'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                        ], 
                    has_rich_preview = True, 
                    id = 'FQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                    image_exif_rotation = 56, 
                    ims = [
                        'DQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                        ], 
                    is_external = True, 
                    is_public = True, 
                    is_starred = True, 
                    is_tombstoned = True, 
                    last_editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    mimetype = '', 
                    mode = '', 
                    name = '', 
                    non_owner_editable = True, 
                    num_stars = 56, 
                    original_h = 56, 
                    original_w = 56, 
                    permalink = '', 
                    permalink_public = '', 
                    pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                    pinned_to = [
                        'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                        ], 
                    pretty_type = '', 
                    preview = '', 
                    public_url_shared = True, 
                    reactions = [
                        slack_beta_ti.models.reaction_object.Reaction object(
                            count = 56, 
                            name = '', 
                            users = [
                                'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                                ], )
                        ], 
                    shares = slack_beta_ti.models.shares.shares(), 
                    size = 56, 
                    source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    state = '', 
                    thumb_1024 = '', 
                    thumb_1024_h = 56, 
                    thumb_1024_w = 56, 
                    thumb_160 = '', 
                    thumb_360 = '', 
                    thumb_360_h = 56, 
                    thumb_360_w = 56, 
                    thumb_480 = '', 
                    thumb_480_h = 56, 
                    thumb_480_w = 56, 
                    thumb_64 = '', 
                    thumb_720 = '', 
                    thumb_720_h = 56, 
                    thumb_720_w = 56, 
                    thumb_80 = '', 
                    thumb_800 = '', 
                    thumb_800_h = 56, 
                    thumb_800_w = 56, 
                    thumb_960 = '', 
                    thumb_960_h = 56, 
                    thumb_960_w = 56, 
                    thumb_tiny = '', 
                    timestamp = 56, 
                    title = '', 
                    updated = 56, 
                    url_private = '', 
                    url_private_download = '', 
                    user = '', 
                    user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                    username = '', ),
                files = [
                    slack_beta_ti.models.file_object.file object(
                        channels = [
                            'CQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                            ], 
                        comments_count = 56, 
                        created = 56, 
                        date_delete = 56, 
                        display_as_bot = True, 
                        editable = True, 
                        editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        external_id = '', 
                        external_type = '', 
                        external_url = '', 
                        filetype = '', 
                        groups = [
                            'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        has_rich_preview = True, 
                        id = 'FQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', 
                        image_exif_rotation = 56, 
                        ims = [
                            'DQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        is_external = True, 
                        is_public = True, 
                        is_starred = True, 
                        is_tombstoned = True, 
                        last_editor = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        mimetype = '', 
                        mode = '', 
                        name = '', 
                        non_owner_editable = True, 
                        num_stars = 56, 
                        original_h = 56, 
                        original_w = 56, 
                        permalink = '', 
                        permalink_public = '', 
                        pinned_info = slack_beta_ti.models.info_for_a_pinned_item.Info for a pinned item(), 
                        pinned_to = [
                            'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                            ], 
                        pretty_type = '', 
                        preview = '', 
                        public_url_shared = True, 
                        reactions = [
                            slack_beta_ti.models.reaction_object.Reaction object(
                                count = 56, 
                                name = '', 
                                users = [
                                    'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                                    ], )
                            ], 
                        shares = slack_beta_ti.models.shares.shares(), 
                        size = 56, 
                        source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        state = '', 
                        thumb_1024 = '', 
                        thumb_1024_h = 56, 
                        thumb_1024_w = 56, 
                        thumb_160 = '', 
                        thumb_360 = '', 
                        thumb_360_h = 56, 
                        thumb_360_w = 56, 
                        thumb_480 = '', 
                        thumb_480_h = 56, 
                        thumb_480_w = 56, 
                        thumb_64 = '', 
                        thumb_720 = '', 
                        thumb_720_h = 56, 
                        thumb_720_w = 56, 
                        thumb_80 = '', 
                        thumb_800 = '', 
                        thumb_800_h = 56, 
                        thumb_800_w = 56, 
                        thumb_960 = '', 
                        thumb_960_h = 56, 
                        thumb_960_w = 56, 
                        thumb_tiny = '', 
                        timestamp = 56, 
                        title = '', 
                        updated = 56, 
                        url_private = '', 
                        url_private_download = '', 
                        user = '', 
                        user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8', 
                        username = '', )
                    ],
                icons = None,
                inviter = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                is_delayed_message = True,
                is_intro = True,
                is_starred = True,
                last_read = '0480728880.015280',
                latest_reply = '0480728880.015280',
                name = '',
                old_name = '',
                parent_user_id = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                permalink = '',
                pinned_to = [
                    'GQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0'
                    ],
                purpose = '',
                reactions = [
                    slack_beta_ti.models.reaction_object.Reaction object(
                        count = 56, 
                        name = '', 
                        users = [
                            'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                            ], )
                    ],
                reply_count = 56,
                reply_users = [
                    'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
                    ],
                reply_users_count = 56,
                source_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                subscribed = True,
                subtype = '',
                team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                text = '',
                thread_ts = '0480728880.015280',
                topic = '',
                ts = '0480728880.015280',
                type = '',
                unread_count = 56,
                upload = True,
                user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                user_profile = slack_beta_ti.models.objs_user_profile_short.objs_user_profile_short(
                    avatar_hash = '', 
                    display_name = '', 
                    display_name_normalized = '', 
                    image_72 = '', 
                    is_restricted = True, 
                    is_ultra_restricted = True, 
                    name = '', 
                    real_name = '', 
                    real_name_normalized = '', 
                    team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0', ),
                user_team = 'TQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8IQ37LLR1PLNJKTGOS9HDVPWI4JDIXDXXML6JAJ4SWHSA0',
                username = ''
            )
        else:
            return ObjsMessage(
                text = '',
                ts = '0480728880.015280',
                type = '',
        )
        """

    def testObjsMessage(self):
        """Test ObjsMessage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.models.objs_reminder import ObjsReminder

class TestObjsReminder(unittest.TestCase):
    """ObjsReminder unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ObjsReminder:
        """Test ObjsReminder
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ObjsReminder`
        """
        model = ObjsReminder()
        if include_optional:
            return ObjsReminder(
                complete_ts = 56,
                creator = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                id = 'Rm8Q6ZGCKEC0L3O4GI7XH',
                recurring = True,
                text = '',
                time = 56,
                user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8'
            )
        else:
            return ObjsReminder(
                creator = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
                id = 'Rm8Q6ZGCKEC0L3O4GI7XH',
                recurring = True,
                text = '',
                user = 'WQ6ZGCKEC0L3O4GI7XHK0JCY075UA034PGMUG8',
        )
        """

    def testObjsReminder(self):
        """Test ObjsReminder"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Slack Web API

    One way to interact with the Slack platform is its HTTP RPC-based Web API, a collection of methods requiring OAuth 2.0-based user, bot, or workspace tokens blessed with related OAuth scopes.

    The version of the OpenAPI document: 1.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from slack_beta_ti.api.chat_api import ChatApi


class TestChatApi(unittest.TestCase):
    """ChatApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ChatApi()

    def tearDown(self) -> None:
        pass

    def test_chat_delete(self) -> None:
        """Test case for chat_delete

        """
        pass

    def test_chat_delete_scheduled_message(self) -> None:
        """Test case for chat_delete_scheduled_message

        """
        pass

    def test_chat_get_permalink(self) -> None:
        """Test case for chat_get_permalink

        """
        pass

    def test_chat_me_message(self) -> None:
        """Test case for chat_me_message

        """
        pass

    def test_chat_post_ephemeral(self) -> None:
        """Test case for chat_post_ephemeral

        """
        pass

    def test_chat_post_message(self) -> None:
        """Test case for chat_post_message

        """
        pass

    def test_chat_schedule_message(self) -> None:
        """Test case for chat_schedule_message

        """
        pass

    def test_chat_scheduled_messages_list(self) -> None:
        """Test case for chat_scheduled_messages_list

        """
        pass

    def test_chat_unfurl(self) -> None:
        """Test case for chat_unfurl

        """
        pass

    def test_chat_update(self) -> None:
        """Test case for chat_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
